import { IVpc } from 'aws-cdk-lib/aws-ec2';
import { IRole } from 'aws-cdk-lib/aws-iam';
import { IKey } from 'aws-cdk-lib/aws-kms';
import { ILogGroup } from 'aws-cdk-lib/aws-logs';
import { IDomain } from 'aws-cdk-lib/aws-opensearchservice';
import { Construct } from 'constructs';
import { OpenSearchClusterProps } from './opensearch-props';
import { TrackedConstruct } from '../../../utils';
/**
 * A construct to provision Amazon OpenSearch Cluster and OpenSearch Dashboards.
 * Uses IAM Identity Center SAML authentication.
 * If OpenSearch cluster is deployed in vpc created using DataVpc construct,
 * ClientVPNEndpoint will be provisioned automatically for secure access to OpenSearch Dashboards.
 *
 * @example
 *  const osCluster = new dsf.consumption.OpenSearchCluster(this, 'MyOpenSearchCluster',{
 *    domainName:"mycluster2",
 *    samlEntityId:'<IdpIdentityId>',
 *    samlMetadataContent:'<IdpMetadataXml>',
 *    samlMasterBackendRole:'<IAMIdentityCenterAdminGroupId>',
 *    deployInVpc:true,
 *    removalPolicy:cdk.RemovalPolicy.DESTROY
 *  });
 *
 *  osCluster.addRoleMapping('DashBoardUser', 'dashboards_user','<IAMIdentityCenterDashboardUsersGroupId>');
 *  osCluster.addRoleMapping('ReadAllRole', 'readall','<IAMIdentityCenterDashboardUsersGroupId>');
 *
 *
*/
export declare class OpenSearchCluster extends TrackedConstruct {
    /**
     * OpenSearchCluster domain
     */
    readonly domain: IDomain;
    /**
     * CloudWatch Logs Log Group to store OpenSearch cluster logs
     */
    readonly logGroup: ILogGroup;
    /**
     * The KMS Key used to encrypt data and logs
     */
    readonly encryptionKey: IKey;
    /**
     * VPC OpenSearch cluster is provisioned in.
     */
    readonly vpc: IVpc | undefined;
    /**
     * CDK Custom resource provider for calling OpenSearch APIs
     */
    private readonly apiProvider;
    /**
     * IAM Role used to provision and configure OpenSearch domain
     */
    readonly masterRole: IRole;
    private prevCr?;
    /**
     * The removal policy when deleting the CDK resource.
     * Resources like Amazon cloudwatch log or Amazon S3 bucket
     * If DESTROY is selected, the context value '@data-solutions-framework-on-aws/removeDataOnDestroy'
     * in the 'cdk.json' or 'cdk.context.json' must be set to true
     * @default - The resources are not deleted (`RemovalPolicy.RETAIN`).
     */
    private removalPolicy;
    /**
     * Constructs a new instance of the OpenSearchCluster class
     * @param {Construct} scope the Scope of the AWS CDK Construct
     * @param {string} id the ID of the AWS CDK Construct
     * @param {OpenSearchClusterProps} props the OpenSearchCluster [properties]{@link OpenSearchClusterProps}
     */
    constructor(scope: Construct, id: string, props: OpenSearchClusterProps);
    /**
     * Calls OpenSearch API using custom resource.
     * @param id The CDK resource ID
     * @param apiPath  OpenSearch API path
     * @param body  OpenSearch API request body
     */
    callOpenSearchApi(id: string, apiPath: string, body: any): void;
    /**
     * @public
     * Add a new role mapping to the cluster.
     * This method is used to add a role mapping to the Amazon OpenSearch cluster
     * @param id The CDK resource ID
     * @param name OpenSearch role name @see https://opensearch.org/docs/2.9/security/access-control/users-roles/#predefined-roles
     * @param role IAM Identity center SAML group Id
     */
    addRoleMapping(id: string, name: string, role: string): void;
}
